@@ -7,9 +7,9 @@ use warnings;
 use subroutines 'Data::Sah::Coerce::js::To_date::From_obj::date';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-11-28'; # DATE
+our $DATE = '2022-09-22'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 1;
 # ABSTRACT: Coerce date from Date object
@@ -26,7 +26,7 @@ Data::Sah::Coerce::js::To_datenotime::From_obj::date - Coerce date from Date obj
 
 =head1 VERSION
 
-This document describes version 0.052 of Data::Sah::Coerce::js::To_datenotime::From_obj::date (from Perl distribution Data-Sah-Coerce), released on 2021-11-28.
+This document describes version 0.053 of Data::Sah::Coerce::js::To_datenotime::From_obj::date (from Perl distribution Data-Sah-Coerce), released on 2022-09-22.
 
 =head1 SYNOPSIS
 
@@ -65,13 +65,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
