@@ -4,9 +4,9 @@ use 5.010001;
 use strict 'subs', 'vars';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-11-28'; # DATE
+our $DATE = '2022-09-22'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.052'; # VERSION
+our $VERSION = '0.053'; # VERSION
 
 our $SUPPORT_OLD_PREFIX = $ENV{PERL_DATA_SAH_COERCE_SUPPORT_OLD_PREFIX} // 1;
 
@@ -16,7 +16,7 @@ our %Default_Rules = (
         datenotime => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
         date       => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
         datetime   => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
-        duration   => [qw/From_float::seconds From_obj::datetime_duration From_str::human From_str::iso8601/],
+        duration   => [qw/From_float::seconds From_obj::datetime_duration From_str::hms From_str::human From_str::iso8601/],
         float      => [qw/From_str::percent/],
         num        => [qw/From_str::percent/],
         timeofday  => [qw/From_obj::date_timeofday From_str::hms/],
@@ -163,7 +163,7 @@ sub get_coerce_rules {
             # new name
         } else {
             die "Invalid syntax for coercion rule item '$item', please ".
-                "only use From_<type>::<description>";
+                "only use (!)?From_<type>::<description>";
         }
         if ($is_exclude) {
             @rules0 = grep { $_ ne $rule_name } @rules0;
@@ -247,7 +247,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.052 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2021-11-28.
+This document describes version 0.053 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2022-09-22.
 
 =head1 FUNCTIONS
 
@@ -355,13 +355,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
